@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use Carp 'croak', 'carp';
 
+require Rstats;
 use Rstats::Element;
 use Scalar::Util ();
 use Math::Complex ();
@@ -2293,4 +2294,8 @@ sub not_equal {
   }
 }
 
+=head1 NAME
+
+Rstats::ElementFunc - Element functions
+
 1;
